@@ -1,6 +1,6 @@
 from typing import cast
 
-from lms.common.lms_datatype import LMS_DataType
+from lms.common.lms_datatype import LMS_DataType, is_string_datatype
 from lms.fileio.io import FileReader, FileWriter
 from lms.message.definitions.field.io import read_field, write_field
 from lms.message.definitions.field.lms_field import LMS_Field, LMS_FieldMap
@@ -29,12 +29,12 @@ def read_decoded_parameters(
         param_offset = reader.tell()
         try:
             if param.datatype is LMS_DataType.STRING:
-                value = LMS_Field(reader.read_len_string_variable_encoding(), param)
+                value = LMS_Field(reader.read_len_string_encoded(), param)
             else:
                 value = read_field(reader, param)
         except Exception as e:
             raise LMS_TagReadingError(
-                f"An error occured reading tag '[{definition.group_name}:{definition.tag_name}]', parameter '{param.name}' at offset {param_offset}"
+                f"An error occurred reading tag '[{definition.group_name}:{definition.tag_name}]', parameter '{param.name}' at offset {param_offset}"
             ) from e
 
         parameters[param.name] = value
@@ -54,8 +54,7 @@ def write_decoded_parameters(
     param_size = 0
 
     for field in parameters:
-        if field.datatype is LMS_DataType.STRING:
-            field.value = cast(str, field.value)
+        if is_string_datatype(field.value, field.datatype):
             param_size += 2 + len(field.value) * writer.encoding.width
         else:
             param_size += field.datatype.stream_size
@@ -67,9 +66,7 @@ def write_decoded_parameters(
 
     for field in parameters:
         try:
-            if field.datatype is LMS_DataType.STRING:
-                field.value = cast(str, field.value)
-
+            if is_string_datatype(field.value, field.datatype):
                 # Tags are padded by a 0xCD byte if the size is not aligned to the encoding
                 # This can occur before a string parameter, or at the end of the tag.
                 # If a string parameter exists, then the padding will always be at the first string instance
@@ -77,12 +74,12 @@ def write_decoded_parameters(
                     writer.write_bytes(TAG_PADDING_BYTE)
                     needs_padding = False
 
-                writer.write_len_variable_encoding_string(field.value)
+                writer.write_len_encoded_string(field.value)
             else:
                 write_field(writer, field)
         except Exception as e:
             raise LMS_TagWritingException(
-                f"An error occured in tag [{group_name}:{tag_name} writing parameter '{field.name}' at offset {writer.tell()}!"
+                f"An error occurred in tag [{group_name}:{tag_name} writing parameter '{field.name}' at offset {writer.tell()}!"
             ) from e
 
     if needs_padding:
