@@ -1,29 +1,24 @@
 import re
-from typing import TypeGuard, runtime_checkable
+from typing import TypeGuard
 
-from lms.message.definitions.field.lms_field import (LMS_Field, LMS_FieldMap,
-                                                     convert_string_to_type)
+from lms.message.definitions.field.lms_field import LMS_FieldMap
 from lms.message.tag.lms_tagexceptions import LMS_InvalidTagFormatError
 from lms.titleconfig.definitions.tags import TagConfig, TagDefinition
 
 TAG_PADDING_CHAR = "CD"
 
-type LMS_ControlTag = LMS_EncodedTag | LMS_DecodedTag
-
-
-def is_tag(obj: object) -> TypeGuard[LMS_ControlTag]:
-    return isinstance(obj, (LMS_EncodedTag, LMS_DecodedTag))
-
 
 class LMS_EncodedTag:
-    """A class that represents an encoded tag.
+    """
+    A class that represents an encoded tag.
 
     Example encoded tags:
         - `[0:3 00-00-00-FF]`
         - `[0:4]`
-        - `[1:0 01-00-00-CD]`"""
+        - `[1:0 01-00-00-CD]`
+    """
 
-    TAG_FORMAT = re.compile(r"\[\s*(\/)?\s*(\d+)\s*:\s*(\d+)(?:[^\]]*)\]")
+    TAG_FORMAT = re.compile(r"\[\s*(/)?\s*(\d+)\s*:\s*(\d+)[^]]*]")
     PARAMETER_FORMAT = re.compile(r"^\s*([0-9A-Fa-f]{2})(\s*-\s*[0-9A-Fa-f]{2})*\s*$")
 
     def __init__(
@@ -41,6 +36,9 @@ class LMS_EncodedTag:
         self._is_fallback = is_fallback
         self._is_closing = is_closing
 
+    def __len__(self) -> int:
+        return len(self.to_text())
+
     @property
     def group_id(self) -> int:
         """The group id for the tag."""
@@ -118,14 +116,18 @@ class LMS_EncodedTag:
 
 
 class LMS_DecodedTag:
-    """A class that represents a decoded tag.
+    """
+    A class that represents a decoded tag.
 
-    Example encoded tags:
+    Example decoded tags:
         - `[System:Color r="0" g="255" b="255" a="255"]`
-        - `[System:Pagebreak]`
-        - `[Mii:Nickname buffer="1" type="Text" conversion="None"]`"""
+        - `[System:PageBreak]`
+        - `[Mii:Nickname buffer="1" type="Text" conversion="None"]`
+    """
 
-    TAG_FORMAT = re.compile(r"\[\s*(/)?\s*(\w+)\s*:\s*(\w+)(?:\s+[^\]]*)?\s*\]")
+    TAG_FORMAT = re.compile(
+        r"\[\s*(/)?\s*([A-Za-z]\w*)\s*:\s*([A-Za-z]+)(?:\s+[^]]*)?\s*]"
+    )
     PARAMETER_FORMAT = re.compile(r'(\w+)="([^"]*)"')
 
     def __init__(
@@ -139,6 +141,9 @@ class LMS_DecodedTag:
 
         self._is_closing = is_closing
 
+    def __len__(self) -> int:
+        return len(self.to_text())
+
     @property
     def group_id(self) -> int:
         """The group id for the tag."""
@@ -182,11 +187,11 @@ class LMS_DecodedTag:
             return f"[{self._definition.group_name}:{self._definition.tag_name}]"
 
         parameters = []
-        for key, param in self._parameters.items():
+        for param in self._parameters:
             if isinstance(param.value, bytes):
-                parameters.append(f'{key}="{param.value.hex()}"')
+                parameters.append(f'{param.name}="{param.value.hex()}"')
             else:
-                parameters.append(f'{key}="{param.value}"')
+                parameters.append(f'{param.name}="{param.value}"')
 
         parameters = " ".join(parameters)
         return (
@@ -208,12 +213,15 @@ class LMS_DecodedTag:
             return cls(tag_definition, is_closing=True)
 
         parameters = dict(cls.PARAMETER_FORMAT.findall(tag))
-
-        parameter_map = {}
-        for definition in tag_definition.parameters:
-            casted_value = convert_string_to_type(
-                parameters[definition.name], definition.datatype
-            )
-            parameter_map[definition.name] = LMS_Field(casted_value, definition)
-
+        parameter_map = LMS_FieldMap.from_string_dict(
+            parameters, tag_definition.parameters
+        )
         return cls(tag_definition, parameter_map)
+
+
+type LMS_ControlTag = LMS_EncodedTag | LMS_DecodedTag
+
+
+def is_tag(obj: object) -> TypeGuard[LMS_ControlTag]:
+    """Typeguard to narrow tag objects."""
+    return isinstance(obj, (LMS_EncodedTag, LMS_DecodedTag))
