@@ -12,6 +12,6 @@ def read_strings(reader: FileReader, four_byte_count: bool) -> list[str]:
 
     for offset in reader.read_offset_array(count):
         reader.seek(offset)
-        string_list.append(reader.read_str_variable_encoding())
+        string_list.append(reader.read_encoded_string())
 
     return string_list
