@@ -13,14 +13,14 @@ def read_tgp2(reader: FileReader) -> list[LMS_TagParamDefinition]:
         datatype = LMS_DataType(reader.read_uint8())
 
         if datatype is not LMS_DataType.LIST:
-            name = reader.read_str_variable_encoding()
+            name = reader.read_encoded_string()
             parameter_info.append(LMS_TagParamDefinition(name, datatype))
             continue
 
         reader.skip(1)
         list_count = reader.read_uint16()
         list_indexes = reader.read_uint16_array(list_count)
-        name = reader.read_str_variable_encoding()
+        name = reader.read_encoded_string()
         parameter_info.append(
             LMS_TagParamDefinition(name, LMS_DataType.LIST, list_indexes)
         )
