@@ -23,11 +23,11 @@ class TitleConfig:
     def __init__(
         self,
         game: str | None,
-        attribute_configs: dict[str, AttributeConfig] | None = None,
+        attribute_config_map: dict[str, AttributeConfig] | None = None,
         tag_config: TagConfig | None = None,
     ):
         self._game = game
-        self._attribute_configs = attribute_configs
+        self._attribute_config_map = attribute_config_map
         self._tag_config = tag_config
 
     @property
@@ -35,16 +35,34 @@ class TitleConfig:
         """The name of the game for the titleconfig."""
         return self._game
 
-    @property
-    def attribute_configs(self) -> dict[str, AttributeConfig] | None:
-        """The map of attribute config instances."""
-        return self._attribute_configs
-
     @property
     def tag_config(self) -> TagConfig | None:
         """The loaded tag config instance."""
         return self._tag_config
 
+    @property
+    def attribute_configs(self) -> tuple[AttributeConfig, ...]:
+        """Returns a tuple of all attribute configurations in read-only form."""
+        if self._attribute_config_map is None:
+            return ()
+        return tuple(self._attribute_config_map.values())
+
+    def get_attribute_config(self, name: str) -> AttributeConfig:
+        """
+        Returns the attribute configuration given the name.
+
+        :param name: the name of the attribute config.
+        """
+        if self._attribute_config_map is None:
+            raise ValueError(f"There are no attribute configs!")
+
+        if name not in self._attribute_config_map:
+            raise KeyError(
+                f"The attribute config '{name}' does not exist in the TitleConfig!"
+            )
+
+        return self._attribute_config_map[name]
+
     @classmethod
     def load_preset(cls, game: str):
         """
@@ -139,7 +157,7 @@ class TitleConfig:
 
         if project.tag_groups is not None:
             config[TitleConfig.TAG_KEY] = {
-                "groups": {group.id: group.name for group in project.tag_groups},
+                "groups": {group.group_id: group.name for group in project.tag_groups},
                 "tags": [],
             }
 
@@ -148,7 +166,7 @@ class TitleConfig:
 
                     definition = {
                         "name": tag_def.name,
-                        "group_id": group.id,
+                        "group_id": group.group_id,
                         "tag_index": i,
                         "description": "",
                         "parameters": None if not tag_def.parameter_definitions else [],
@@ -172,10 +190,10 @@ class TitleConfig:
                     config[TitleConfig.TAG_KEY]["tags"].append(definition)
 
         config[TitleConfig.ATTR_KEY] = []
-        if project.attribute_info is not None:
+        if project.attribute_definitions is not None:
 
             attr_definitions = []
-            for attr_def in project.attribute_info:
+            for attr_def in project.attribute_definitions:
                 definition = {
                     "name": attr_def.name,
                     "description": "",
